# sc-pred

## Description
Python package for cell identity recognition at individual cell level from single-cell RNA-seq data.<br/><br/>
Cell types for unknown cells are predicted, through a statistical approach, using raw gene expresssion <br/>
data among a list of cells, and a gene marker dataset consisting of a list of genes found in known cell types/gene sets.<br/><br/>
sc-pred is based off of the
- R software: https://github.com/RausellLab/CelliD
- CelliD statistical method presented in the article: <a href="https://www.nature.com/articles/s41587-021-00896-6.epdf?sharing_token=cb8TdGrz0o3PXjXn_wZGCdRgN0jAjWel9jnR3ZoTv0Oa3WzvJLtg4J6wv_eRGblv7pCmV-VB-3abW6uWDvAeOER7rbNPidd1IsRjFITIK8SJ_d0RrfACjtlZFkN4l3DDZLXWnaDW2XZDF1uZ-2DWCHQNkva9vqKjz708F5zU2FU%3D">Gene signature extraction and cell identity recognition at the single-cell level with Cell-ID, Nature Biotechnology 2021</a>

Please take a look at the <a href="https://github.com/RockLee117/sc-pred">README.md</a> in the repository for further understanding of the implementation.

## Author
- Ramin Mohammadi, rammoh5346@gmail.com

## License

This package is under the GNU General Public License v3.0